contexttools.detach_context_marks_attached_to_component
=======================================================

.. autofunction:: abjad.tools.contexttools.detach_context_marks_attached_to_component.detach_context_marks_attached_to_component
